@@ -8,8 +8,8 @@ async def get_rate_limit_url(method_name, *args, **kwargs):
             kwargs["method"] = arg
     return await asyncGetRequest(url, kwargs)
     
-async def log_response(method_name, response_data, *args, **kwargs):
-    url = ("/log_response")
+async def log_response(method_name, response_data,endpoint=None, *args, **kwargs):
+    url = getEndpointUrl(endpoint or "/log_response")
     # Assuming that `args` is supposed to update `kwargs` for unspecified keys
     for arg in args:
         if "method" not in kwargs:
@@ -21,7 +21,7 @@ async def log_response(method_name, response_data, *args, **kwargs):
         "method": kwargs.get("method", method_name),
         "response_data": kwargs.get("response_data", response_data)
     }
-    return await asyncPostRequest(url, kwargs, endpoint=endpoint)
+    return await asyncPostRequest(url, kwargs,endpoint=None)
 
 
 
